@@ -121,6 +121,9 @@ class SegmentMappingSim(MetadynamicSimulation):
             chosen_CVs_all_replicas = []
             for i in range(self.num_replicas):
 
+                self._remove_custom_forces()
+                self._build_custom_forces()
+
                 print('Starting scan run for replica {}'.format(i+1))
 
                 self.simulation.context.reinitialize()
